# -*- coding: UTf-8 -*-


__all__ = ['UNICODE_EMOJI', 'emoji_name']

UNICODE_EMOJI = {
    u'admission_tickets': u'\U0001f39f',
    u'aerial_tramway': u'\U0001f6a1',
    u'airplane': u'\U00002708',
    u'airplane_arriving': u'\U0001f6ec',
    u'airplane_departure': u'\U0001f6eb',
    u'alarm_clock': u'\U000023f0',
    u'alembic': u'\U00002697',
    u'alien_monster': u'\U0001f47e',
    u'ambulance': u'\U0001f691',
    u'american_football': u'\U0001f3c8',
    u'amphora': u'\U0001f3fa',
    u'anchor': u'\U00002693',
    u'anger_symbol': u'\U0001f4a2',
    u'angry_face': u'\U0001f620',
    u'anguished_face': u'\U0001f627',
    u'ant': u'\U0001f41c',
    u'antenna_with_bars': u'\U0001f4f6',
    u'anticlockwise_downwards_and_upwards_open_circle_arrows': u'\U0001f504',
    u'aquarius': u'\U00002652',
    u'aries': u'\U00002648',
    u'arrow_pointing_rightwards_then_curving_downwards': u'\U00002935',
    u'arrow_pointing_rightwards_then_curving_upwards': u'\U00002934',
    u'articulated_lorry': u'\U0001f69b',
    u'artist_palette': u'\U0001f3a8',
    u'astonished_face': u'\U0001f632',
    u'athletic_shoe': u'\U0001f45f',
    u'atom_symbol': u'\U0000269b',
    u'aubergine': u'\U0001f346',
    u'automated_teller_machine': u'\U0001f3e7',
    u'automobile': u'\U0001f697',
    u'baby': u'\U0001f476',
    u'baby_angel': u'\U0001f47c',
    u'baby_bottle': u'\U0001f37c',
    u'baby_chick': u'\U0001f424',
    u'baby_symbol': u'\U0001f6bc',
    u'back_with_leftwards_arrow_above': u'\U0001f519',
    u'bactrian_camel': u'\U0001f42b',
    u'badminton_racquet_and_shuttlecock': u'\U0001f3f8',
    u'baggage_claim': u'\U0001f6c4',
    u'balloon': u'\U0001f388',
    u'ballot_box_with_ballot': u'\U0001f5f3',
    u'ballot_box_with_check': u'\U00002611',
    u'banana': u'\U0001f34c',
    u'bank': u'\U0001f3e6',
    u'banknote_with_dollar_sign': u'\U0001f4b5',
    u'banknote_with_euro_sign': u'\U0001f4b6',
    u'banknote_with_pound_sign': u'\U0001f4b7',
    u'banknote_with_yen_sign': u'\U0001f4b4',
    u'bar_chart': u'\U0001f4ca',
    u'barber_pole': u'\U0001f488',
    u'baseball': u'\U000026be',
    u'basketball_and_hoop': u'\U0001f3c0',
    u'bath': u'\U0001f6c0',
    u'bathtub': u'\U0001f6c1',
    u'battery': u'\U0001f50b',
    u'beach_with_umbrella': u'\U0001f3D6',
    u'bear_face': u'\U0001f43b',
    u'beating_heart': u'\U0001f493',
    u'bed': u'\U0001f6cf',
    u'beer_mug': u'\U0001f37a',
    u'bell': u'\U0001f514',
    u'bell_with_cancellation_stroke': u'\U0001f515',
    u'bellhop_bell': u'\U0001f6ce',
    u'bento_box': u'\U0001f371',
    u'bicycle': u'\U0001f6b2',
    u'bicyclist': u'\U0001f6b4',
    u'bikini': u'\U0001f459',
    u'billiards': u'\U0001f3b1',
    u'biohazard_sign': u'\U00002623',
    u'bird': u'\U0001f426',
    u'birthday_cake': u'\U0001f382',
    u'black_circle_for_record': u'\U000023fa',
    u'black_club_suit': u'\U00002663',
    u'black_diamond_suit': u'\U00002666',
    u'black_down-pointing_double_triangle': u'\U000023ec',
    u'black_heart_suit': u'\U00002665',
    u'black_large_square': u'\U00002b1b',
    u'black_left-pointing_double_triangle': u'\U000023ea',
    u'black_left-pointing_double_triangle_with_vertical_bar': u'\U000023ee',
    u'black_left-pointing_triangle': u'\U000025c0',
    u'black_medium_small_square': u'\U000025fe',
    u'black_medium_square': u'\U000025fc',
    u'black_nib': u'\U00002712',
    u'black_question_mark_ornament': u'\U00002753',
    u'black_right-pointing_double_triangle': u'\U000023e9',
    u'black_right-pointing_double_triangle_with_vertical_bar': u'\U000023eD',
    u'black_right-pointing_triangle': u'\U000025b6',
    u'black_right-pointing_triangle_with_double_vertical_bar': u'\U000023ef',
    u'black_rightwards_arrow': u'\U000027a1',
    u'black_scissors': u'\U00002702',
    u'black_small_square': u'\U000025aa',
    u'black_spade_suit': u'\U00002660',
    u'black_square_button': u'\U0001f532',
    u'black_square_for_stop': u'\U000023f9',
    u'black_sun_with_rays': u'\U00002600',
    u'black_telephone': u'\U0000260e',
    u'black_universal_recycling_symbol': u'\U0000267b',
    u'black_up-pointing_double_triangle': u'\U000023eb',
    u'blossom': u'\U0001f33c',
    u'blowfish': u'\U0001f421',
    u'blue_book': u'\U0001f4D8',
    u'blue_heart': u'\U0001f499',
    u'boar': u'\U0001f417',
    u'bomb': u'\U0001f4a3',
    u'bookmark': u'\U0001f516',
    u'bookmark_tabs': u'\U0001f4D1',
    u'books': u'\U0001f4Da',
    u'bottle_with_popping_cork': u'\U0001f37e',
    u'bouquet': u'\U0001f490',
    u'bow_and_arrow': u'\U0001f3f9',
    u'bowling': u'\U0001f3b3',
    u'boy': u'\U0001f466',
    u'bread': u'\U0001f35e',
    u'bride_with_veil': u'\U0001f470',
    u'bridge_at_night': u'\U0001f309',
    u'briefcase': u'\U0001f4bc',
    u'broken_heart': u'\U0001f494',
    u'bug': u'\U0001f41b',
    u'building_construction': u'\U0001f3D7',
    u'burrito': u'\U0001f32f',
    u'bus': u'\U0001f68c',
    u'bus_stop': u'\U0001f68f',
    u'bust_in_silhouette': u'\U0001f464',
    u'busts_in_silhouette': u'\U0001f465',
    u'cactus': u'\U0001f335',
    u'calendar': u'\U0001f4c5',
    u'camera': u'\U0001f4f7',
    u'camera_with_flash': u'\U0001f4f8',
    u'camping': u'\U0001f3D5',
    u'cancer': u'\U0000264b',
    u'candle': u'\U0001f56f',
    u'candy': u'\U0001f36c',
    u'capricorn': u'\U00002651',
    u'card_file_box': u'\U0001f5c3',
    u'card_index': u'\U0001f4c7',
    u'card_index_dividers': u'\U0001f5c2',
    u'carousel_horse': u'\U0001f3a0',
    u'carp_streamer': u'\U0001f38f',
    u'cat': u'\U0001f408',
    u'cat_face': u'\U0001f431',
    u'cat_face_with_tears_of_joy': u'\U0001f639',
    u'cat_face_with_wry_smile': u'\U0001f63c',
    u'chains': u'\U000026D3',
    u'chart_with_downwards_trend': u'\U0001f4c9',
    u'chart_with_upwards_trend': u'\U0001f4c8',
    u'chart_with_upwards_trend_and_yen_sign': u'\U0001f4b9',
    u'cheering_megaphone': u'\U0001f4e3',
    u'cheese_wedge': u'\U0001f9c0',
    u'chequered_flag': u'\U0001f3c1',
    u'cherries': u'\U0001f352',
    u'cherry_blossom': u'\U0001f338',
    u'chestnut': u'\U0001f330',
    u'chicken': u'\U0001f414',
    u'children_crossing': u'\U0001f6b8',
    u'chipmunk': u'\U0001f43f',
    u'chocolate_bar': u'\U0001f36b',
    u'christmas_tree': u'\U0001f384',
    u'church': u'\U000026ea',
    u'cinema': u'\U0001f3a6',
    u'circled_ideograph_accept': u'\U0001f251',
    u'circled_ideograph_advantage': u'\U0001f250',
    u'circled_ideograph_congratulation': u'\U00003297',
    u'circled_ideograph_secret': u'\U00003299',
    u'circled_latin_capital_letter_m': u'\U000024c2',
    u'circus_tent': u'\U0001f3aa',
    u'cityscape': u'\U0001f3D9',
    u'cityscape_at_dusk': u'\U0001f306',
    u'clapper_board': u'\U0001f3ac',
    u'clapping_hands_sign': u'\U0001f44f',
    u'classical_building': u'\U0001f3Db',
    u'clinking_beer_mugs': u'\U0001f37b',
    u'clipboard': u'\U0001f4cb',
    u'clock_face_eight-thirty': u'\U0001f563',
    u'clock_face_eight_oclock': u'\U0001f557',
    u'clock_face_eleven-thirty': u'\U0001f566',
    u'clock_face_eleven_oclock': u'\U0001f55a',
    u'clock_face_five-thirty': u'\U0001f560',
    u'clock_face_five_oclock': u'\U0001f554',
    u'clock_face_four-thirty': u'\U0001f55f',
    u'clock_face_four_oclock': u'\U0001f553',
    u'clock_face_nine-thirty': u'\U0001f564',
    u'clock_face_nine_oclock': u'\U0001f558',
    u'clock_face_one-thirty': u'\U0001f55c',
    u'clock_face_one_oclock': u'\U0001f550',
    u'clock_face_seven-thirty': u'\U0001f562',
    u'clock_face_seven_oclock': u'\U0001f556',
    u'clock_face_six-thirty': u'\U0001f561',
    u'clock_face_six_oclock': u'\U0001f555',
    u'clock_face_ten-thirty': u'\U0001f565',
    u'clock_face_ten_oclock': u'\U0001f559',
    u'clock_face_three-thirty': u'\U0001f55e',
    u'clock_face_three_oclock': u'\U0001f552',
    u'clock_face_twelve-thirty': u'\U0001f567',
    u'clock_face_twelve_oclock': u'\U0001f55b',
    u'clock_face_two-thirty': u'\U0001f55D',
    u'clock_face_two_oclock': u'\U0001f551',
    u'clockwise_downwards_and_upwards_open_circle_arrows': u'\U0001f503',
    u'clockwise_rightwards_and_leftwards_open_circle_arrows': u'\U0001f501',
    u'clockwise_rightwards_and_leftwards_open_circle_arrows': u'\U0001f502',
    u'closed_book': u'\U0001f4D5',
    u'closed_lock_with_key': u'\U0001f510',
    u'closed_mailbox_with_lowered_flag': u'\U0001f4ea',
    u'closed_mailbox_with_raised_flag': u'\U0001f4eb',
    u'closed_umbrella': u'\U0001f302',
    u'cloud': u'\U00002601',
    u'cloud_with_lightning': u'\U0001f329',
    u'cloud_with_rain': u'\U0001f327',
    u'cloud_with_snow': u'\U0001f328',
    u'cloud_with_tornado': u'\U0001f32a',
    u'cocktail_glass': u'\U0001f378',
    u'coffin': u'\U000026b0',
    u'collision_symbol': u'\U0001f4a5',
    u'comet': u'\U00002604',
    u'compression': u'\U0001f5Dc',
    u'confetti_ball': u'\U0001f38a',
    u'confounded_face': u'\U0001f616',
    u'confused_face': u'\U0001f615',
    u'construction_sign': u'\U0001f6a7',
    u'construction_worker': u'\U0001f477',
    u'control_knobs': u'\U0001f39b',
    u'convenience_store': u'\U0001f3ea',
    u'cooked_rice': u'\U0001f35a',
    u'cookie': u'\U0001f36a',
    u'cooking': u'\U0001f373',
    u'copyright_sign': u'\U000000a9',
    u'couch_and_lamp': u'\U0001f6cb',
    u'couple_with_heart': u'\U0001f491',
    u'cow': u'\U0001f404',
    u'cow_face': u'\U0001f42e',
    u'crab': u'\U0001f980',
    u'credit_card': u'\U0001f4b3',
    u'crescent_moon': u'\U0001f319',
    u'cricket_bat_and_ball': u'\U0001f3cf',
    u'crocodile': u'\U0001f40a',
    u'cross_mark': u'\U0000274c',
    u'crossed_flags': u'\U0001f38c',
    u'crossed_swords': u'\U00002694',
    u'crown': u'\U0001f451',
    u'crying_cat_face': u'\U0001f63f',
    u'crying_face': u'\U0001f622',
    u'crystal_ball': u'\U0001f52e',
    u'curly_loop': u'\U000027b0',
    u'currency_exchange': u'\U0001f4b1',
    u'curry_and_rice': u'\U0001f35b',
    u'custard': u'\U0001f36e',
    u'customs': u'\U0001f6c3',
    u'cyclone': u'\U0001f300',
    u'dagger_knife': u'\U0001f5e1',
    u'dancer': u'\U0001f483',
    u'dango': u'\U0001f361',
    u'dark_sunglasses': u'\U0001f576',
    u'dash_symbol': u'\U0001f4a8',
    u'deciduous_tree': u'\U0001f333',
    u'delivery_truck': u'\U0001f69a',
    u'department_store': u'\U0001f3ec',
    u'derelict_house_building': u'\U0001f3Da',
    u'desert': u'\U0001f3Dc',
    u'desert_island': u'\U0001f3DD',
    u'desktop_computer': u'\U0001f5a5',
    u'diamond_shape_with_a_dot_inside': u'\U0001f4a0',
    u'direct_hit': u'\U0001f3af',
    u'disappointed_but_relieved_face': u'\U0001f625',
    u'disappointed_face': u'\U0001f61e',
    u'dizzy_face': u'\U0001f635',
    u'dizzy_symbol': u'\U0001f4ab',
    u'do_not_litter_symbol': u'\U0001f6af',
    u'dog': u'\U0001f415',
    u'dog_face': u'\U0001f436',
    u'dolphin': u'\U0001f42c',
    u'door': u'\U0001f6aa',
    u'double_curly_loop': u'\U000027bf',
    u'double_exclamation_mark': u'\U0000203c',
    u'double_vertical_bar': u'\U000023f8',
    u'doughnut': u'\U0001f369',
    u'dove_of_peace': u'\U0001f54a',
    u'down-pointing_red_triangle': u'\U0001f53b',
    u'down-pointing_small_red_triangle': u'\U0001f53D',
    u'downwards_black_arrow': u'\U00002b07',
    u'dragon': u'\U0001f409',
    u'dragon_face': u'\U0001f432',
    u'dress': u'\U0001f457',
    u'dromedary_camel': u'\U0001f42a',
    u'droplet': u'\U0001f4a7',
    u'dvd': u'\U0001f4c0',
    u'e-mail_symbol': u'\U0001f4e7',
    u'ear': u'\U0001f442',
    u'ear_of_maize': u'\U0001f33D',
    u'ear_of_rice': u'\U0001f33e',
    u'earth_globe_americas': u'\U0001f30e',
    u'earth_globe_asia-australia': u'\U0001f30f',
    u'earth_globe_europe-africa': u'\U0001f30D',
    u'eight_pointed_black_star': u'\U00002734',
    u'eight_spoked_asterisk': u'\U00002733',
    u'eject_symbol': u'\U000023cf',
    u'electric_light_bulb': u'\U0001f4a1',
    u'electric_plug': u'\U0001f50c',
    u'electric_torch': u'\U0001f526',
    u'elephant': u'\U0001f418',
    u'emoji_modifier_fitzpatrick_type-1-2': u'\U0001f3fb',
    u'emoji_modifier_fitzpatrick_type-3': u'\U0001f3fc',
    u'emoji_modifier_fitzpatrick_type-4': u'\U0001f3fD',
    u'emoji_modifier_fitzpatrick_type-5': u'\U0001f3fe',
    u'emoji_modifier_fitzpatrick_type-6': u'\U0001f3ff',
    u'end_with_leftwards_arrow_above': u'\U0001f51a',
    u'envelope': u'\U00002709',
    u'envelope_with_downwards_arrow_above': u'\U0001f4e9',
    u'european_castle': u'\U0001f3f0',
    u'european_post_office': u'\U0001f3e4',
    u'evergreen_tree': u'\U0001f332',
    u'exclamation_question_mark': u'\U00002049',
    u'expressionless_face': u'\U0001f611',
    u'extraterrestrial_alien': u'\U0001f47D',
    u'eye': u'\U0001f441',
    u'eyeglasses': u'\U0001f453',
    u'eyes': u'\U0001f440',
    u'face_massage': u'\U0001f486',
    u'face_savouring_delicious_food': u'\U0001f60b',
    u'face_screaming_in_fear': u'\U0001f631',
    u'face_throwing_a_kiss': u'\U0001f618',
    u'face_with_cold_sweat': u'\U0001f613',
    u'face_with_head-bandage': u'\U0001f915',
    u'face_with_look_of_triumph': u'\U0001f624',
    u'face_with_medical_mask': u'\U0001f637',
    u'face_with_no_good_gesture': u'\U0001f645',
    u'face_with_ok_gesture': u'\U0001f646',
    u'face_with_open_mouth': u'\U0001f62e',
    u'face_with_open_mouth_and_cold_sweat': u'\U0001f630',
    u'face_with_rolling_eyes': u'\U0001f644',
    u'face_with_stuck-out_tongue': u'\U0001f61b',
    u'face_with_stuck-out_tongue_and_tightly-closed_eyes': u'\U0001f61D',
    u'face_with_stuck-out_tongue_and_winking_eye': u'\U0001f61c',
    u'face_with_tears_of_joy': u'\U0001f602',
    u'face_with_thermometer': u'\U0001f912',
    u'face_without_mouth': u'\U0001f636',
    u'factory': u'\U0001f3eD',
    u'fallen_leaf': u'\U0001f342',
    u'family': u'\U0001f46a',
    u'father_christmas': u'\U0001f385',
    u'fax_machine': u'\U0001f4e0',
    u'fearful_face': u'\U0001f628',
    u'ferris_wheel': u'\U0001f3a1',
    u'ferry': u'\U000026f4',
    u'field_hockey_stick_and_ball': u'\U0001f3D1',
    u'file_cabinet': u'\U0001f5c4',
    u'file_folder': u'\U0001f4c1',
    u'film_frames': u'\U0001f39e',
    u'film_projector': u'\U0001f4fD',
    u'fire': u'\U0001f525',
    u'fire_engine': u'\U0001f692',
    u'firework_sparkler': u'\U0001f387',
    u'fireworks': u'\U0001f386',
    u'first_quarter_moon_symbol': u'\U0001f313',
    u'first_quarter_moon_with_face': u'\U0001f31b',
    u'fish': u'\U0001f41f',
    u'fish_cake_with_swirl_design': u'\U0001f365',
    u'fishing_pole_and_fish': u'\U0001f3a3',
    u'fisted_hand_sign': u'\U0001f44a',
    u'flag_for_afghanistan': u'\U0001f1e6\U0001f1eb',
    u'flag_for_albania': u'\U0001f1e6\U0001f1f1',
    u'flag_for_algeria': u'\U0001f1e9\U0001f1ff',
    u'flag_for_american_Samoa': u'\U0001f1e6\U0001f1f8',
    u'flag_for_andorra': u'\U0001f1e6\U0001f1e9',
    u'flag_for_angola': u'\U0001f1e6\U0001f1f4',
    u'flag_for_anguilla': u'\U0001f1e6\U0001f1ee',
    u'flag_for_antarctica': u'\U0001f1e6\U0001f1f6',
    u'flag_for_antigua_&_barbuda': u'\U0001f1e6\U0001f1ec',
    u'flag_for_argentina': u'\U0001f1e6\U0001f1f7',
    u'flag_for_armenia': u'\U0001f1e6\U0001f1f2',
    u'flag_for_aruba': u'\U0001f1e6\U0001f1fc',
    u'flag_for_ascension_Island': u'\U0001f1e6\U0001f1e8',
    u'flag_for_australia': u'\U0001f1e6\U0001f1fa',
    u'flag_for_austria': u'\U0001f1e6\U0001f1f9',
    u'flag_for_azerbaijan': u'\U0001f1e6\U0001f1ff',
    u'flag_for_bahamas': u'\U0001f1e7\U0001f1f8',
    u'flag_for_bahrain': u'\U0001f1e7\U0001f1eD',
    u'flag_for_bangladesh': u'\U0001f1e7\U0001f1e9',
    u'flag_for_barbados': u'\U0001f1e7\U0001f1e7',
    u'flag_for_belarus': u'\U0001f1e7\U0001f1fe',
    u'flag_for_belgium': u'\U0001f1e7\U0001f1ea',
    u'flag_for_belize': u'\U0001f1e7\U0001f1ff',
    u'flag_for_benin': u'\U0001f1e7\U0001f1ef',
    u'flag_for_bermuda': u'\U0001f1e7\U0001f1f2',
    u'flag_for_bhutan': u'\U0001f1e7\U0001f1f9',
    u'flag_for_bolivia': u'\U0001f1e7 \U0001f1f4',
    u'flag_for_bosnia_&_Herzegovina': u'\U0001f1e7\U0001f1e6',
    u'flag_for_botswana': u'\U0001f1e7\U0001f1fc',
    u'flag_for_bouvet_Island': u'\U0001f1e7\U0001f1fb',
    u'flag_for_brazil': u'\U0001f1e7\U0001f1f7',
    u'flag_for_british_Indian_Ocean_Territory': u'\U0001f1ee\U0001f1f4',
    u'flag_for_british_Virgin_Islands': u'\U0001f1fb\U0001f1ec',
    u'flag_for_brunei': u'\U0001f1e7\U0001f1f3',
    u'flag_for_bulgaria': u'\U0001f1e7\U0001f1ec',
    u'flag_for_burkina_faso': u'\U0001f1e7\U0001f1eb',
    u'flag_for_burundi': u'\U0001f1e7\U0001f1ee',
    u'flag_for_cambodia': u'\U0001f1f0\U0001f1eD',
    u'flag_for_cameroon': u'\U0001f1e8\U0001f1f2',
    u'flag_for_canada': u'\U0001f1e8\U0001f1e6',
    u'flag_for_canary_Islands': u'\U0001f1ee\U0001f1e8',
    u'flag_for_cape_Verde': u'\U0001f1e8\U0001f1fb',
    u'flag_for_caribbean_Netherlands': u'\U0001f1e7\U0001f1f6',
    u'flag_for_cayman_Islands': u'\U0001f1f0\U0001f1fe',
    u'flag_for_central_african_Republic': u'\U0001f1e8\U0001f1eb',
    u'flag_for_ceuta_&_Melilla': u'\U0001f1ea\U0001f1e6',
    u'flag_for_chad': u'\U0001f1f9\U0001f1e9',
    u'flag_for_chile': u'\U0001f1e8\U0001f1f1',
    u'flag_for_china': u'\U0001f1e8\U0001f1f3',
    u'flag_for_christmas_Island': u'\U0001f1e8\U0001f1fD',
    u'flag_for_clipperton_Island': u'\U0001f1e8\U0001f1f5',
    u'flag_for_cocos__Islands': u'\U0001f1e8\U0001f1e8',
    u'flag_for_colombia': u'\U0001f1e8\U0001f1f4',
    u'flag_for_comoros': u'\U0001f1f0\U0001f1f2',
    u'flag_for_congo_-_brazzaville': u'\U0001f1e8\U0001f1ec',
    u'flag_for_congo_-_Kinshasa': u'\U0001f1e8\U0001f1e9',
    u'flag_for_cook_Islands': u'\U0001f1e8\U0001f1f0',
    u'flag_for_costa_Rica': u'\U0001f1e8\U0001f1f7',
    u'flag_for_croatia': u'\U0001f1eD\U0001f1f7',
    u'flag_for_cuba': u'\U0001f1e8\U0001f1fa',
    u'flag_for_curaçao': u'\U0001f1e8\U0001f1fc',
    u'flag_for_cyprus': u'\U0001f1e8\U0001f1fe',
    u'flag_for_czech_Republic': u'\U0001f1e8\U0001f1ff',
    u'flag_for_côte_d’Ivoire': u'\U0001f1e8\U0001f1ee',
    u'flag_for_Denmark': u'\U0001f1e9\U0001f1f0',
    u'flag_for_Diego_Garcia': u'\U0001f1e9\U0001f1ec',
    u'flag_for_Djibouti': u'\U0001f1e9\U0001f1ef',
    u'flag_for_Dominica': u'\U0001f1e9\U0001f1f2',
    u'flag_for_Dominican_Republic': u'\U0001f1e9\U0001f1f4',
    u'flag_for_ecuador': u'\U0001f1ea\U0001f1e8',
    u'flag_for_egypt': u'\U0001f1ea\U0001f1ec',
    u'flag_for_el_Salvador': u'\U0001f1f8\U0001f1fb',
    u'flag_for_equatorial_Guinea': u'\U0001f1ec\U0001f1f6',
    u'flag_for_eritrea': u'\U0001f1ea\U0001f1f7',
    u'flag_for_estonia': u'\U0001f1ea\U0001f1ea',
    u'flag_for_ethiopia': u'\U0001f1ea\U0001f1f9',
    u'flag_for_european_Union': u'\U0001f1ea\U0001f1fa',
    u'flag_for_falkland_Islands': u'\U0001f1eb\U0001f1f0',
    u'flag_for_faroe_Islands': u'\U0001f1eb\U0001f1f4',
    u'flag_for_fiji': u'\U0001f1eb\U0001f1ef',
    u'flag_for_finland': u'\U0001f1eb\U0001f1ee',
    u'flag_for_france': u'\U0001f1eb\U0001f1f7',
    u'flag_for_french_Guiana': u'\U0001f1ec\U0001f1eb',
    u'flag_for_french_Polynesia': u'\U0001f1f5\U0001f1eb',
    u'flag_for_french_Southern_Territories': u'\U0001f1f9\U0001f1eb',
    u'flag_for_Gabon': u'\U0001f1ec\U0001f1e6',
    u'flag_for_Gambia': u'\U0001f1ec\U0001f1f2',
    u'flag_for_Georgia': u'\U0001f1ec\U0001f1ea',
    u'flag_for_Germany': u'\U0001f1e9\U0001f1ea',
    u'flag_for_Ghana': u'\U0001f1ec\U0001f1eD',
    u'flag_for_Gibraltar': u'\U0001f1ec\U0001f1ee',
    u'flag_for_Greece': u'\U0001f1ec\U0001f1f7',
    u'flag_for_Greenland': u'\U0001f1ec\U0001f1f1',
    u'flag_for_Grenada': u'\U0001f1ec\U0001f1e9',
    u'flag_for_Guadeloupe': u'\U0001f1ec\U0001f1f5',
    u'flag_for_Guam': u'\U0001f1ec\U0001f1fa',
    u'flag_for_Guatemala': u'\U0001f1ec\U0001f1f9',
    u'flag_for_Guernsey': u'\U0001f1ec\U0001f1ec',
    u'flag_for_Guinea': u'\U0001f1ec\U0001f1f3',
    u'flag_for_Guinea-bissau': u'\U0001f1ec\U0001f1fc',
    u'flag_for_Guyana': u'\U0001f1ec\U0001f1fe',
    u'flag_for_Haiti': u'\U0001f1eD\U0001f1f9',
    u'flag_for_Heard_&_McDonald_Islands': u'\U0001f1eD\U0001f1f2',
    u'flag_for_Honduras': u'\U0001f1eD\U0001f1f3',
    u'flag_for_Hong_Kong': u'\U0001f1eD\U0001f1f0',
    u'flag_for_Hungary': u'\U0001f1eD\U0001f1fa',
    u'flag_for_Iceland': u'\U0001f1ee\U0001f1f8',
    u'flag_for_India': u'\U0001f1ee\U0001f1f3',
    u'flag_for_Indonesia': u'\U0001f1ee\U0001f1e9',
    u'flag_for_Iran': u'\U0001f1ee\U0001f1f7',
    u'flag_for_Iraq': u'\U0001f1ee\U0001f1f6',
    u'flag_for_Ireland': u'\U0001f1ee\U0001f1ea',
    u'flag_for_Isle_of_Man': u'\U0001f1ee\U0001f1f2',
    u'flag_for_Israel': u'\U0001f1ee\U0001f1f1',
    u'flag_for_Italy': u'\U0001f1ee\U0001f1f9',
    u'flag_for_Jamaica': u'\U0001f1ef\U0001f1f2',
    u'flag_for_Japan': u'\U0001f1ef\U0001f1f5',
    u'flag_for_Jersey': u'\U0001f1ef\U0001f1ea',
    u'flag_for_Jordan': u'\U0001f1ef\U0001f1f4',
    u'flag_for_Kazakhstan': u'\U0001f1f0\U0001f1ff',
    u'flag_for_Kenya': u'\U0001f1f0\U0001f1ea',
    u'flag_for_Kiribati': u'\U0001f1f0\U0001f1ee',
    u'flag_for_Kosovo': u'\U0001f1fD\U0001f1f0',
    u'flag_for_Kuwait': u'\U0001f1f0\U0001f1fc',
    u'flag_for_Kyrgyzstan': u'\U0001f1f0\U0001f1ec',
    u'flag_for_Laos': u'\U0001f1f1\U0001f1e6',
    u'flag_for_Latvia': u'\U0001f1f1\U0001f1fb',
    u'flag_for_Lebanon': u'\U0001f1f1\U0001f1e7',
    u'flag_for_Lesotho': u'\U0001f1f1\U0001f1f8',
    u'flag_for_Liberia': u'\U0001f1f1\U0001f1f7',
    u'flag_for_Libya': u'\U0001f1f1\U0001f1fe',
    u'flag_for_Liechtenstein': u'\U0001f1f1\U0001f1ee',
    u'flag_for_Lithuania': u'\U0001f1f1\U0001f1f9',
    u'flag_for_Luxembourg': u'\U0001f1f1\U0001f1fa',
    u'flag_for_Macau': u'\U0001f1f2\U0001f1f4',
    u'flag_for_Macedonia': u'\U0001f1f2\U0001f1f0',
    u'flag_for_Madagascar': u'\U0001f1f2\U0001f1ec',
    u'flag_for_Malawi': u'\U0001f1f2\U0001f1fc',
    u'flag_for_Malaysia': u'\U0001f1f2\U0001f1fe',
    u'flag_for_Maldives': u'\U0001f1f2\U0001f1fb',
    u'flag_for_Mali': u'\U0001f1f2\U0001f1f1',
    u'flag_for_Malta': u'\U0001f1f2\U0001f1f9',
    u'flag_for_Marshall_Islands': u'\U0001f1f2\U0001f1eD',
    u'flag_for_Martinique': u'\U0001f1f2\U0001f1f6',
    u'flag_for_Mauritania': u'\U0001f1f2\U0001f1f7',
    u'flag_for_Mauritius': u'\U0001f1f2\U0001f1fa',
    u'flag_for_Mayotte': u'\U0001f1fe\U0001f1f9',
    u'flag_for_Mexico': u'\U0001f1f2\U0001f1fD',
    u'flag_for_Micronesia': u'\U0001f1eb\U0001f1f2',
    u'flag_for_Moldova': u'\U0001f1f2\U0001f1e9',
    u'flag_for_Monaco': u'\U0001f1f2\U0001f1e8',
    u'flag_for_Mongolia': u'\U0001f1f2\U0001f1f3',
    u'flag_for_Montenegro': u'\U0001f1f2\U0001f1ea',
    u'flag_for_Montserrat': u'\U0001f1f2\U0001f1f8',
    u'flag_for_Morocco': u'\U0001f1f2\U0001f1e6',
    u'flag_for_Mozambique': u'\U0001f1f2\U0001f1ff',
    u'flag_for_Myanmar': u'\U0001f1f2\U0001f1f2',
    u'flag_for_Namibia': u'\U0001f1f3\U0001f1e6',
    u'flag_for_Nauru': u'\U0001f1f3\U0001f1f7',
    u'flag_for_Nepal': u'\U0001f1f3\U0001f1f5',
    u'flag_for_Netherlands': u'\U0001f1f3\U0001f1f1',
    u'flag_for_New_caledonia': u'\U0001f1f3\U0001f1e8',
    u'flag_for_New_Zealand': u'\U0001f1f3\U0001f1ff',
    u'flag_for_Nicaragua': u'\U0001f1f3\U0001f1ee',
    u'flag_for_Niger': u'\U0001f1f3\U0001f1ea',
    u'flag_for_Nigeria': u'\U0001f1f3\U0001f1ec',
    u'flag_for_Niue': u'\U0001f1f3\U0001f1fa',
    u'flag_for_Norfolk_Island': u'\U0001f1f3\U0001f1eb',
    u'flag_for_North_Korea': u'\U0001f1f0\U0001f1f5',
    u'flag_for_Northern_Mariana_Islands': u'\U0001f1f2\U0001f1f5',
    u'flag_for_Norway': u'\U0001f1f3\U0001f1f4',
    u'flag_for_Oman': u'\U0001f1f4\U0001f1f2',
    u'flag_for_Pakistan': u'\U0001f1f5\U0001f1f0',
    u'flag_for_Palau': u'\U0001f1f5\U0001f1fc',
    u'flag_for_Palestinian_Territories': u'\U0001f1f5\U0001f1f8',
    u'flag_for_Panama': u'\U0001f1f5\U0001f1e6',
    u'flag_for_Papua_New_Guinea': u'\U0001f1f5\U0001f1ec',
    u'flag_for_Paraguay': u'\U0001f1f5\U0001f1fe',
    u'flag_for_Peru': u'\U0001f1f5\U0001f1ea',
    u'flag_for_Philippines': u'\U0001f1f5\U0001f1eD',
    u'flag_for_Pitcairn_Islands': u'\U0001f1f5\U0001f1f3',
    u'flag_for_Poland': u'\U0001f1f5\U0001f1f1',
    u'flag_for_Portugal': u'\U0001f1f5\U0001f1f9',
    u'flag_for_Puerto_Rico': u'\U0001f1f5\U0001f1f7',
    u'flag_for_Qatar': u'\U0001f1f6\U0001f1e6',
    u'flag_for_Romania': u'\U0001f1f7\U0001f1f4',
    u'flag_for_Russia': u'\U0001f1f7\U0001f1fa',
    u'flag_for_Rwanda': u'\U0001f1f7\U0001f1fc',
    u'flag_for_Réunion': u'\U0001f1f7\U0001f1ea',
    u'flag_for_Samoa': u'\U0001f1fc\U0001f1f8',
    u'flag_for_San_Marino': u'\U0001f1f8\U0001f1f2',
    u'flag_for_Saudi_arabia': u'\U0001f1f8\U0001f1e6',
    u'flag_for_Senegal': u'\U0001f1f8\U0001f1f3',
    u'flag_for_Serbia': u'\U0001f1f7\U0001f1f8',
    u'flag_for_Seychelles': u'\U0001f1f8\U0001f1e8',
    u'flag_for_Sierra_Leone': u'\U0001f1f8\U0001f1f1',
    u'flag_for_Singapore': u'\U0001f1f8\U0001f1ec',
    u'flag_for_Sint_Maarten': u'\U0001f1f8\U0001f1fD',
    u'flag_for_Slovakia': u'\U0001f1f8\U0001f1f0',
    u'flag_for_Slovenia': u'\U0001f1f8\U0001f1ee',
    u'flag_for_Solomon_Islands': u'\U0001f1f8\U0001f1e7',
    u'flag_for_Somalia': u'\U0001f1f8\U0001f1f4',
    u'flag_for_South_africa': u'\U0001f1ff\U0001f1e6',
    u'flag_for_South_Georgia_&_South_Sandwich_Island': u'\U0001f1ec\U0001f1f8',
    u'flag_for_South_Korea': u'\U0001f1f0\U0001f1f7',
    u'flag_for_South_Sudan': u'\U0001f1f8\U0001f1f8',
    u'flag_for_Spain': u'\U0001f1ea\U0001f1f8',
    u'flag_for_Sri_Lanka': u'\U0001f1f1\U0001f1f0',
    u'flag_for_St._barthélemy': u'\U0001f1e7\U0001f1f1',
    u'flag_for_St._Helena': u'\U0001f1f8\U0001f1eD',
    u'flag_for_St._Kitts_&_Nevis': u'\U0001f1f0\U0001f1f3',
    u'flag_for_St._Lucia': u'\U0001f1f1\U0001f1e8',
    u'flag_for_St._Martin': u'\U0001f1f2\U0001f1eb',
    u'flag_for_St._Pierre_&_Miquelon': u'\U0001f1f5\U0001f1f2',
    u'flag_for_St._Vincent_&_Grenadines': u'\U0001f1fb\U0001f1e8',
    u'flag_for_Sudan': u'\U0001f1f8\U0001f1e9',
    u'flag_for_Suriname': u'\U0001f1f8\U0001f1f7',
    u'flag_for_Svalbard_&_Jan_Mayen': u'\U0001f1f8\U0001f1ef',
    u'flag_for_Swaziland': u'\U0001f1f8\U0001f1ff',
    u'flag_for_Sweden': u'\U0001f1f8\U0001f1ea',
    u'flag_for_Switzerland': u'\U0001f1e8\U0001f1eD',
    u'flag_for_Syria': u'\U0001f1f8\U0001f1fe',
    u'flag_for_São_Tomé_&_Príncipe': u'\U0001f1f8\U0001f1f9',
    u'flag_for_Taiwan': u'\U0001f1f9\U0001f1fc',
    u'flag_for_Tajikistan': u'\U0001f1f9\U0001f1ef',
    u'flag_for_Tanzania': u'\U0001f1f9\U0001f1ff',
    u'flag_for_Thailand': u'\U0001f1f9\U0001f1eD',
    u'flag_for_Timor-Leste': u'\U0001f1f9\U0001f1f1',
    u'flag_for_Togo': u'\U0001f1f9\U0001f1ec',
    u'flag_for_Tokelau': u'\U0001f1f9\U0001f1f0',
    u'flag_for_Tonga': u'\U0001f1f9\U0001f1f4',
    u'flag_for_Trinidad_&_Tobago': u'\U0001f1f9\U0001f1f9',
    u'flag_for_Tristan_da_cunha': u'\U0001f1f9\U0001f1e6',
    u'flag_for_Tunisia': u'\U0001f1f9\U0001f1f3',
    u'flag_for_Turkey': u'\U0001f1f9\U0001f1f7',
    u'flag_for_Turkmenistan': u'\U0001f1f9\U0001f1f2',
    u'flag_for_Turks_&_caicos_Islands': u'\U0001f1f9\U0001f1e8',
    u'flag_for_Tuvalu': u'\U0001f1f9\U0001f1fb',
    u'flag_for_U.S._Outlying_Islands': u'\U0001f1fa\U0001f1f2',
    u'flag_for_U.S._Virgin_Islands': u'\U0001f1fb\U0001f1ee',
    u'flag_for_Uganda': u'\U0001f1fa\U0001f1ec',
    u'flag_for_Ukraine': u'\U0001f1fa\U0001f1e6',
    u'flag_for_United_arab_emirates': u'\U0001f1e6\U0001f1ea',
    u'flag_for_United_Kingdom': u'\U0001f1ec\U0001f1e7',
    u'flag_for_United_States': u'\U0001f1fa\U0001f1f8',
    u'flag_for_Uruguay': u'\U0001f1fa\U0001f1fe',
    u'flag_for_Uzbekistan': u'\U0001f1fa\U0001f1ff',
    u'flag_for_Vanuatu': u'\U0001f1fb\U0001f1fa',
    u'flag_for_Vatican_city': u'\U0001f1fb\U0001f1e6',
    u'flag_for_Venezuela': u'\U0001f1fb\U0001f1ea',
    u'flag_for_Vietnam': u'\U0001f1fb\U0001f1f3',
    u'flag_for_Wallis_&_futuna': u'\U0001f1fc\U0001f1eb',
    u'flag_for_Western_Sahara': u'\U0001f1ea\U0001f1eD',
    u'flag_for_Yemen': u'\U0001f1fe\U0001f1ea',
    u'flag_for_Zambia': u'\U0001f1ff\U0001f1f2',
    u'flag_for_Zimbabwe': u'\U0001f1ff\U0001f1fc',
    u'flag_for_Åland_Islands': u'\U0001f1e6\U0001f1fD',
    u'flag_in_hole': u'\U000026f3',
    u'fleur-de-lis': u'\U0000269c',
    u'flexed_biceps': u'\U0001f4aa',
    u'floppy_disk': u'\U0001f4be',
    u'flower_playing_cards': u'\U0001f3b4',
    u'flushed_face': u'\U0001f633',
    u'fog': u'\U0001f32b',
    u'foggy': u'\U0001f301',
    u'footprints': u'\U0001f463',
    u'fork_and_knife': u'\U0001f374',
    u'fork_and_knife_with_plate': u'\U0001f37D',
    u'fountain': u'\U000026f2',
    u'four_leaf_clover': u'\U0001f340',
    u'frame_with_picture': u'\U0001f5bc',
    u'french_fries': u'\U0001f35f',
    u'fried_shrimp': u'\U0001f364',
    u'frog_face': u'\U0001f438',
    u'front-facing_baby_chick': u'\U0001f425',
    u'frowning_face_with_open_mouth': u'\U0001f626',
    u'fuel_pump': u'\U000026fD',
    u'full_moon_symbol': u'\U0001f315',
    u'full_moon_with_face': u'\U0001f31D',
    u'funeral_urn': u'\U000026b1',
    u'game_die': u'\U0001f3b2',
    u'gear': u'\U00002699',
    u'gem_stone': u'\U0001f48e',
    u'gemini': u'\U0000264a',
    u'ghost': u'\U0001f47b',
    u'girl': u'\U0001f467',
    u'globe_with_meridians': u'\U0001f310',
    u'glowing_star': u'\U0001f31f',
    u'goat': u'\U0001f410',
    u'golfer': u'\U0001f3cc',
    u'graduation_cap': u'\U0001f393',
    u'grapes': u'\U0001f347',
    u'green_apple': u'\U0001f34f',
    u'green_book': u'\U0001f4D7',
    u'green_heart': u'\U0001f49a',
    u'grimacing_face': u'\U0001f62c',
    u'grinning_cat_face_with_smiling_eyes': u'\U0001f638',
    u'grinning_face': u'\U0001f600',
    u'grinning_face_with_smiling_eyes': u'\U0001f601',
    u'growing_heart': u'\U0001f497',
    u'guardsman': u'\U0001f482',
    u'guitar': u'\U0001f3b8',
    u'haircut': u'\U0001f487',
    u'hamburger': u'\U0001f354',
    u'hammer': u'\U0001f528',
    u'hammer_and_pick': u'\U00002692',
    u'hammer_and_wrench': u'\U0001f6e0',
    u'hamster_face': u'\U0001f439',
    u'handbag': u'\U0001f45c',
    u'happy_person_raising_one_hand': u'\U0001f64b',
    u'hatching_chick': u'\U0001f423',
    u'headphone': u'\U0001f3a7',
    u'hear-no-evil_monkey': u'\U0001f649',
    u'heart_decoration': u'\U0001f49f',
    u'heart_with_arrow': u'\U0001f498',
    u'heart_with_ribbon': u'\U0001f49D',
    u'heavy_black_heart': u'\U00002764',
    u'heavy_check_mark': u'\U00002714',
    u'heavy_division_sign': u'\U00002797',
    u'heavy_dollar_sign': u'\U0001f4b2',
    u'heavy_exclamation_mark_symbol': u'\U00002757',
    u'heavy_heart_exclamation_mark_ornament': u'\U00002763',
    u'heavy_large_circle': u'\U00002b55',
    u'heavy_minus_sign': u'\U00002796',
    u'heavy_multiplication_x': u'\U00002716',
    u'heavy_plus_sign': u'\U00002795',
    u'helicopter': u'\U0001f681',
    u'helm_symbol': u'\U00002388',
    u'helmet_with_white_cross': u'\U000026D1',
    u'herb': u'\U0001f33f',
    u'hibiscus': u'\U0001f33a',
    u'high-heeled_shoe': u'\U0001f460',
    u'high-speed_train': u'\U0001f684',
    u'high-speed_train_with_bullet_nose': u'\U0001f685',
    u'high_brightness_symbol': u'\U0001f506',
    u'high_voltage_sign': u'\U000026a1',
    u'hocho': u'\U0001f52a',
    u'hole': u'\U0001f573',
    u'honey_pot': u'\U0001f36f',
    u'honeybee': u'\U0001f41D',
    u'horizontal_traffic_light': u'\U0001f6a5',
    u'horse': u'\U0001f40e',
    u'horse_face': u'\U0001f434',
    u'horse_racing': u'\U0001f3c7',
    u'hospital': u'\U0001f3e5',
    u'hot_beverage': u'\U00002615',
    u'hot_dog': u'\U0001f32D',
    u'hot_pepper': u'\U0001f336',
    u'hot_springs': u'\U00002668',
    u'hotel': u'\U0001f3e8',
    u'hourglass': u'\U0000231b',
    u'hourglass_with_flowing_sand': u'\U000023f3',
    u'house_building': u'\U0001f3e0',
    u'house_buildings': u'\U0001f3D8',
    u'house_with_garden': u'\U0001f3e1',
    u'hugging_face': u'\U0001f917',
    u'hundred_points_symbol': u'\U0001f4af',
    u'hushed_face': u'\U0001f62f',
    u'ice_cream': u'\U0001f368',
    u'ice_hockey_stick_and_puck': u'\U0001f3D2',
    u'ice_skate': u'\U000026f8',
    u'imp': u'\U0001f47f',
    u'inbox_tray': u'\U0001f4e5',
    u'incoming_envelope': u'\U0001f4e8',
    u'information_desk_person': u'\U0001f481',
    u'information_source': u'\U00002139',
    u'input_symbol_for_latin_capital_letters': u'\U0001f520',
    u'input_symbol_for_latin_letters': u'\U0001f524',
    u'input_symbol_for_latin_small_letters': u'\U0001f521',
    u'input_symbol_for_numbers': u'\U0001f522',
    u'input_symbol_for_symbols': u'\U0001f523',
    u'izakaya_lantern': u'\U0001f3ee',
    u'jack-o-lantern': u'\U0001f383',
    u'japanese_castle': u'\U0001f3ef',
    u'japanese_dolls': u'\U0001f38e',
    u'japanese_goblin': u'\U0001f47a',
    u'japanese_ogre': u'\U0001f479',
    u'japanese_post_office': u'\U0001f3e3',
    u'japanese_symbol_for_beginner': u'\U0001f530',
    u'jeans': u'\U0001f456',
    u'joystick': u'\U0001f579',
    u'kaaba': u'\U0001f54b',
    u'key': u'\U0001f511',
    u'keyboard': u'\U00002328',
    u'keycap_asterisk': u'\U0000002a \U000020e3',
    u'keycap_digit_eight': u'\U00000038 \U000020e3',
    u'keycap_digit_five': u'\U00000035 \U000020e3',
    u'keycap_digit_four': u'\U00000034 \U000020e3',
    u'keycap_digit_nine': u'\U00000039 \U000020e3',
    u'keycap_digit_one': u'\U00000031 \U000020e3',
    u'keycap_digit_seven': u'\U00000037 \U000020e3',
    u'keycap_digit_six': u'\U00000036 \U000020e3',
    u'keycap_digit_three': u'\U00000033 \U000020e3',
    u'keycap_digit_two': u'\U00000032 \U000020e3',
    u'keycap_digit_zero': u'\U00000030 \U000020e3',
    u'keycap_number_sign': u'\U00000023 \U000020e3',
    u'keycap_ten': u'\U0001f51f',
    u'kimono': u'\U0001f458',
    u'kiss': u'\U0001f48f',
    u'kiss_mark': u'\U0001f48b',
    u'kissing_cat_face_with_closed_eyes': u'\U0001f63D',
    u'kissing_face': u'\U0001f617',
    u'kissing_face_with_closed_eyes': u'\U0001f61a',
    u'kissing_face_with_smiling_eyes': u'\U0001f619',
    u'koala': u'\U0001f428',
    u'label': u'\U0001f3f7',
    u'lady_beetle': u'\U0001f41e',
    u'large_blue_circle': u'\U0001f535',
    u'large_blue_diamond': u'\U0001f537',
    u'large_orange_diamond': u'\U0001f536',
    u'large_red_circle': u'\U0001f534',
    u'last_quarter_moon_symbol': u'\U0001f317',
    u'last_quarter_moon_with_face': u'\U0001f31c',
    u'latin_cross': u'\U0000271D',
    u'leaf_fluttering_in_wind': u'\U0001f343',
    u'ledger': u'\U0001f4D2',
    u'left-pointing_magnifying_glass': u'\U0001f50D',
    u'left_luggage': u'\U0001f6c5',
    u'left_right_arrow': u'\U00002194',
    u'leftwards_arrow_with_hook': u'\U000021a9',
    u'leftwards_black_arrow': u'\U00002b05',
    u'lemon': u'\U0001f34b',
    u'leo': u'\U0000264c',
    u'leopard': u'\U0001f406',
    u'level_slider': u'\U0001f39a',
    u'libra': u'\U0000264e',
    u'light_rail': u'\U0001f688',
    u'link_symbol': u'\U0001f517',
    u'linked_paperclips': u'\U0001f587',
    u'lion_face': u'\U0001f981',
    u'lipstick': u'\U0001f484',
    u'lock': u'\U0001f512',
    u'lock_with_ink_pen': u'\U0001f50f',
    u'lollipop': u'\U0001f36D',
    u'loudly_crying_face': u'\U0001f62D',
    u'love_hotel': u'\U0001f3e9',
    u'love_letter': u'\U0001f48c',
    u'low_brightness_symbol': u'\U0001f505',
    u'lower_left_ballpoint_pen': u'\U0001f58a',
    u'lower_left_crayon': u'\U0001f58D',
    u'lower_left_fountain_pen': u'\U0001f58b',
    u'lower_left_paintbrush': u'\U0001f58c',
    u'mahjong_tile_red_dragon': u'\U0001f004',
    u'man': u'\U0001f468',
    u'man_and_woman_holding_hands': u'\U0001f46b',
    u'man_in_business_suit_levitating': u'\U0001f574',
    u'man_with_gua_pi_mao': u'\U0001f472',
    u'man_with_turban': u'\U0001f473',
    u'mans_shoe': u'\U0001f45e',
    u'mantelpiece_clock': u'\U0001f570',
    u'maple_leaf': u'\U0001f341',
    u'meat_on_bone': u'\U0001f356',
    u'medium_black_circle': u'\U000026ab',
    u'medium_white_circle': u'\U000026aa',
    u'melon': u'\U0001f348',
    u'memo': u'\U0001f4DD',
    u'menorah_with_nine_branches': u'\U0001f54e',
    u'mens_symbol': u'\U0001f6b9',
    u'metro': u'\U0001f687',
    u'microphone': u'\U0001f3a4',
    u'microscope': u'\U0001f52c',
    u'military_medal': u'\U0001f396',
    u'milky_way': u'\U0001f30c',
    u'minibus': u'\U0001f690',
    u'minidisc': u'\U0001f4bD',
    u'mobile_phone': u'\U0001f4f1',
    u'mobile_phone_off': u'\U0001f4f4',
    u'mobile_phone_with_rightwards_arrow_at_left': u'\U0001f4f2',
    u'money-mouth_face': u'\U0001f911',
    u'money_bag': u'\U0001f4b0',
    u'money_with_wings': u'\U0001f4b8',
    u'monkey': u'\U0001f412',
    u'monkey_face': u'\U0001f435',
    u'monorail': u'\U0001f69D',
    u'moon_viewing_ceremony': u'\U0001f391',
    u'mosque': u'\U0001f54c',
    u'motor_boat': u'\U0001f6e5',
    u'motorway': u'\U0001f6e3',
    u'mount_fuji': u'\U0001f5fb',
    u'mountain': u'\U000026f0',
    u'mountain_bicyclist': u'\U0001f6b5',
    u'mountain_cableway': u'\U0001f6a0',
    u'mountain_railway': u'\U0001f69e',
    u'mouse': u'\U0001f401',
    u'mouse_face': u'\U0001f42D',
    u'mouth': u'\U0001f444',
    u'movie_camera': u'\U0001f3a5',
    u'moyai': u'\U0001f5ff',
    u'multiple_musical_notes': u'\U0001f3b6',
    u'mushroom': u'\U0001f344',
    u'musical_keyboard': u'\U0001f3b9',
    u'musical_note': u'\U0001f3b5',
    u'musical_score': u'\U0001f3bc',
    u'nail_polish': u'\U0001f485',
    u'name_badge': u'\U0001f4Db',
    u'national_park': u'\U0001f3De',
    u'necktie': u'\U0001f454',
    u'negative_squared_ab': u'\U0001f18e',
    u'negative_squared_cross_mark': u'\U0000274e',
    u'negative_squared_latin_capital_letter_a': u'\U0001f170',
    u'negative_squared_latin_capital_letter_b': u'\U0001f171',
    u'negative_squared_latin_capital_letter_o': u'\U0001f17e',
    u'negative_squared_latin_capital_letter_p': u'\U0001f17f',
    u'nerd_face': u'\U0001f913',
    u'neutral_face': u'\U0001f610',
    u'new_moon_symbol': u'\U0001f311',
    u'new_moon_with_face': u'\U0001f31a',
    u'newspaper': u'\U0001f4f0',
    u'night_with_stars': u'\U0001f303',
    u'no_bicycles': u'\U0001f6b3',
    u'no_entry': u'\U000026D4',
    u'no_entry_sign': u'\U0001f6ab',
    u'no_mobile_phones': u'\U0001f4f5',
    u'no_one_under_eighteen_symbol': u'\U0001f51e',
    u'no_pedestrians': u'\U0001f6b7',
    u'no_smoking_symbol': u'\U0001f6aD',
    u'non-potable_water_symbol': u'\U0001f6b1',
    u'north_east_arrow': u'\U00002197',
    u'north_west_arrow': u'\U00002196',
    u'nose': u'\U0001f443',
    u'notebook': u'\U0001f4D3',
    u'notebook_with_decorative_cover': u'\U0001f4D4',
    u'nut_and_bolt': u'\U0001f529',
    u'octopus': u'\U0001f419',
    u'oden': u'\U0001f362',
    u'office_building': u'\U0001f3e2',
    u'oil_drum': u'\U0001f6e2',
    u'ok_hand_sign': u'\U0001f44c',
    u'old_key': u'\U0001f5DD',
    u'older_man': u'\U0001f474',
    u'older_woman': u'\U0001f475',
    u'om_symbol': u'\U0001f549',
    u'on_with_exclamation_mark_with_left_right_arrow_above': u'\U0001f51b',
    u'oncoming_automobile': u'\U0001f698',
    u'oncoming_bus': u'\U0001f68D',
    u'oncoming_police_car': u'\U0001f694',
    u'oncoming_taxi': u'\U0001f696',
    u'open_book': u'\U0001f4D6',
    u'open_file_folder': u'\U0001f4c2',
    u'open_hands_sign': u'\U0001f450',
    u'open_lock': u'\U0001f513',
    u'open_mailbox_with_lowered_flag': u'\U0001f4eD',
    u'open_mailbox_with_raised_flag': u'\U0001f4ec',
    u'ophiuchus': u'\U000026ce',
    u'optical_disc': u'\U0001f4bf',
    u'orange_book': u'\U0001f4D9',
    u'orthodox_cross': u'\U00002626',
    u'outbox_tray': u'\U0001f4e4',
    u'ox': u'\U0001f402',
    u'package': u'\U0001f4e6',
    u'page_facing_up': u'\U0001f4c4',
    u'page_with_curl': u'\U0001f4c3',
    u'pager': u'\U0001f4Df',
    u'palm_tree': u'\U0001f334',
    u'panda_face': u'\U0001f43c',
    u'paperclip': u'\U0001f4ce',
    u'part_alternation_mark': u'\U0000303D',
    u'party_popper': u'\U0001f389',
    u'passenger_ship': u'\U0001f6f3',
    u'passport_control': u'\U0001f6c2',
    u'paw_prints': u'\U0001f43e',
    u'peace_symbol': u'\U0000262e',
    u'peach': u'\U0001f351',
    u'pear': u'\U0001f350',
    u'pedestrian': u'\U0001f6b6',
    u'pencil': u'\U0000270f',
    u'penguin': u'\U0001f427',
    u'pensive_face': u'\U0001f614',
    u'performing_arts': u'\U0001f3aD',
    u'persevering_face': u'\U0001f623',
    u'person_bowing_deeply': u'\U0001f647',
    u'person_frowning': u'\U0001f64D',
    u'person_raising_both_hands_in_celebration': u'\U0001f64c',
    u'person_with_ball': u'\U000026f9',
    u'person_with_blond_hair': u'\U0001f471',
    u'person_with_folded_hands': u'\U0001f64f',
    u'person_with_pouting_face': u'\U0001f64e',
    u'personal_computer': u'\U0001f4bb',
    u'pick': u'\U000026cf',
    u'pig': u'\U0001f416',
    u'pig_face': u'\U0001f437',
    u'pig_nose': u'\U0001f43D',
    u'pile_of_poo': u'\U0001f4a9',
    u'pill': u'\U0001f48a',
    u'pine_decoration': u'\U0001f38D',
    u'pineapple': u'\U0001f34D',
    u'pisces': u'\U00002653',
    u'pistol': u'\U0001f52b',
    u'place_of_worship': u'\U0001f6D0',
    u'playing_card_black_joker': u'\U0001f0cf',
    u'police_car': u'\U0001f693',
    u'police_cars_revolving_light': u'\U0001f6a8',
    u'police_officer': u'\U0001f46e',
    u'poodle': u'\U0001f429',
    u'popcorn': u'\U0001f37f',
    u'postal_horn': u'\U0001f4ef',
    u'postbox': u'\U0001f4ee',
    u'pot_of_food': u'\U0001f372',
    u'potable_water_symbol': u'\U0001f6b0',
    u'pouch': u'\U0001f45D',
    u'poultry_leg': u'\U0001f357',
    u'pouting_cat_face': u'\U0001f63e',
    u'pouting_face': u'\U0001f621',
    u'prayer_beads': u'\U0001f4ff',
    u'princess': u'\U0001f478',
    u'printer': u'\U0001f5a8',
    u'public_address_loudspeaker': u'\U0001f4e2',
    u'purple_heart': u'\U0001f49c',
    u'purse': u'\U0001f45b',
    u'pushpin': u'\U0001f4cc',
    u'put_litter_in_its_place_symbol': u'\U0001f6ae',
    u'rabbit': u'\U0001f407',
    u'rabbit_face': u'\U0001f430',
    u'racing_car': u'\U0001f3ce',
    u'racing_motorcycle': u'\U0001f3cD',
    u'radio': u'\U0001f4fb',
    u'radio_button': u'\U0001f518',
    u'radioactive_sign': u'\U00002622',
    u'railway_car': u'\U0001f683',
    u'railway_track': u'\U0001f6e4',
    u'rainbow': u'\U0001f308',
    u'raised_fist': u'\U0000270a',
    u'raised_hand': u'\U0000270b',
    u'raised_hand_with_fingers_splayed': u'\U0001f590',
    u'raised_hand_with_part_between_middle_and_ring_fingers': u'\U0001f596',
    u'ram': u'\U0001f40f',
    u'rat': u'\U0001f400',
    u'recreational_vehicle': u'\U0001f699',
    u'red_apple': u'\U0001f34e',
    u'registered_sign': u'\U000000ae',
    u'relieved_face': u'\U0001f60c',
    u'reminder_ribbon': u'\U0001f397',
    u'restroom': u'\U0001f6bb',
    u'reversed_hand_with_middle_finger_extended': u'\U0001f595',
    u'revolving_hearts': u'\U0001f49e',
    u'ribbon': u'\U0001f380',
    u'rice_ball': u'\U0001f359',
    u'rice_cracker': u'\U0001f358',
    u'right-pointing_magnifying_glass': u'\U0001f50e',
    u'right_anger_bubble': u'\U0001f5ef',
    u'rightwards_arrow_with_hook': u'\U000021aa',
    u'ring': u'\U0001f48D',
    u'roasted_sweet_potato': u'\U0001f360',
    u'robot_face': u'\U0001f916',
    u'rocket': u'\U0001f680',
    u'rolled-up_newspaper': u'\U0001f5De',
    u'roller_coaster': u'\U0001f3a2',
    u'rooster': u'\U0001f413',
    u'rose': u'\U0001f339',
    u'rosette': u'\U0001f3f5',
    u'round_pushpin': u'\U0001f4cD',
    u'rowboat': u'\U0001f6a3',
    u'rugby_football': u'\U0001f3c9',
    u'runner': u'\U0001f3c3',
    u'running_shirt_with_sash': u'\U0001f3bD',
    u'sagittarius': u'\U00002650',
    u'sailboat': u'\U000026f5',
    u'sake_bottle_and_cup': u'\U0001f376',
    u'satellite': u'\U0001f6f0',
    u'satellite_antenna': u'\U0001f4e1',
    u'saxophone': u'\U0001f3b7',
    u'scales': u'\U00002696',
    u'school': u'\U0001f3eb',
    u'school_satchel': u'\U0001f392',
    u'scorpion': u'\U0001f982',
    u'scorpius': u'\U0000264f',
    u'scroll': u'\U0001f4Dc',
    u'seat': u'\U0001f4ba',
    u'see-no-evil_monkey': u'\U0001f648',
    u'seedling': u'\U0001f331',
    u'shamrock': u'\U00002618',
    u'shaved_ice': u'\U0001f367',
    u'sheep': u'\U0001f411',
    u'shield': u'\U0001f6e1',
    u'shinto_shrine': u'\U000026e9',
    u'ship': u'\U0001f6a2',
    u'shooting_star': u'\U0001f320',
    u'shopping_bags': u'\U0001f6cD',
    u'shortcake': u'\U0001f370',
    u'shower': u'\U0001f6bf',
    u'sign_of_the_horns': u'\U0001f918',
    u'silhouette_of_japan': u'\U0001f5fe',
    u'six_pointed_star_with_middle_dot': u'\U0001f52f',
    u'ski_and_ski_boot': u'\U0001f3bf',
    u'skier': u'\U000026f7',
    u'skull': u'\U0001f480',
    u'skull_and_crossbones': u'\U00002620',
    u'sleeping_accommodation': u'\U0001f6cc',
    u'sleeping_face': u'\U0001f634',
    u'sleeping_symbol': u'\U0001f4a4',
    u'sleepy_face': u'\U0001f62a',
    u'sleuth_or_spy': u'\U0001f575',
    u'slice_of_pizza': u'\U0001f355',
    u'slightly_frowning_face': u'\U0001f641',
    u'slightly_smiling_face': u'\U0001f642',
    u'slot_machine': u'\U0001f3b0',
    u'small_airplane': u'\U0001f6e9',
    u'small_blue_diamond': u'\U0001f539',
    u'small_orange_diamond': u'\U0001f538',
    u'smiling_cat_face_with_heart-shaped_eyes': u'\U0001f63b',
    u'smiling_cat_face_with_open_mouth': u'\U0001f63a',
    u'smiling_face_with_halo': u'\U0001f607',
    u'smiling_face_with_heart-shaped_eyes': u'\U0001f60D',
    u'smiling_face_with_horns': u'\U0001f608',
    u'smiling_face_with_open_mouth': u'\U0001f603',
    u'smiling_face_with_open_mouth_and_cold_sweat': u'\U0001f605',
    u'smiling_face_with_open_mouth_and_smiling_eyes': u'\U0001f604',
    u'smiling_face_with_open_mouth_and_tightly-closed_eyes': u'\U0001f606',
    u'smiling_face_with_smiling_eyes': u'\U0001f60a',
    u'smiling_face_with_sunglasses': u'\U0001f60e',
    u'smirking_face': u'\U0001f60f',
    u'smoking_symbol': u'\U0001f6ac',
    u'snail': u'\U0001f40c',
    u'snake': u'\U0001f40D',
    u'snow_capped_mountain': u'\U0001f3D4',
    u'snowboarder': u'\U0001f3c2',
    u'snowflake': u'\U00002744',
    u'snowman': u'\U00002603',
    u'snowman_without_snow': u'\U000026c4',
    u'soccer_ball': u'\U000026bD',
    u'soft_ice_cream': u'\U0001f366',
    u'soon_with_rightwards_arrow_above': u'\U0001f51c',
    u'south_east_arrow': u'\U00002198',
    u'south_west_arrow': u'\U00002199',
    u'spaghetti': u'\U0001f35D',
    u'sparkle': u'\U00002747',
    u'sparkles': u'\U00002728',
    u'sparkling_heart': u'\U0001f496',
    u'speak-no-evil_monkey': u'\U0001f64a',
    u'speaker': u'\U0001f508',
    u'speaker_with_cancellation_stroke': u'\U0001f507',
    u'speaker_with_one_sound_wave': u'\U0001f509',
    u'speaker_with_three_sound_waves': u'\U0001f50a',
    u'speaking_head_in_silhouette': u'\U0001f5e3',
    u'speech_balloon': u'\U0001f4ac',
    u'speedboat': u'\U0001f6a4',
    u'spider': u'\U0001f577',
    u'spider_web': u'\U0001f578',
    u'spiral_calendar_pad': u'\U0001f5D3',
    u'spiral_note_pad': u'\U0001f5D2',
    u'spiral_shell': u'\U0001f41a',
    u'splashing_sweat_symbol': u'\U0001f4a6',
    u'sports_medal': u'\U0001f3c5',
    u'spouting_whale': u'\U0001f433',
    u'squared_cjk_unified_ideograph-5272': u'\U0001f239',
    u'squared_cjk_unified_ideograph-5408': u'\U0001f234',
    u'squared_cjk_unified_ideograph-55b6': u'\U0001f23a',
    u'squared_cjk_unified_ideograph-6307': u'\U0001f22f',
    u'squared_cjk_unified_ideograph-6708': u'\U0001f237',
    u'squared_cjk_unified_ideograph-6709': u'\U0001f236',
    u'squared_cjk_unified_ideograph-6e80': u'\U0001f235',
    u'squared_cjk_unified_ideograph-7121': u'\U0001f21a',
    u'squared_cjk_unified_ideograph-7533': u'\U0001f238',
    u'squared_cjk_unified_ideograph-7981': u'\U0001f232',
    u'squared_cjk_unified_ideograph-7a7a': u'\U0001f233',
    u'squared_cl': u'\U0001f191',
    u'squared_cool': u'\U0001f192',
    u'squared_free': u'\U0001f193',
    u'squared_id': u'\U0001f194',
    u'squared_katakana_koko': u'\U0001f201',
    u'squared_katakana_sa': u'\U0001f202',
    u'squared_new': u'\U0001f195',
    u'squared_ng': u'\U0001f196',
    u'squared_ok': u'\U0001f197',
    u'squared_sos': u'\U0001f198',
    u'squared_up_with_exclamation_mark': u'\U0001f199',
    u'squared_vs': u'\U0001f19a',
    u'stadium': u'\U0001f3Df',
    u'star_and_crescent': u'\U0000262a',
    u'star_of_david': u'\U00002721',
    u'station': u'\U0001f689',
    u'statue_of_liberty': u'\U0001f5fD',
    u'steam_locomotive': u'\U0001f682',
    u'steaming_bowl': u'\U0001f35c',
    u'stopwatch': u'\U000023f1',
    u'straight_ruler': u'\U0001f4cf',
    u'strawberry': u'\U0001f353',
    u'studio_microphone': u'\U0001f399',
    u'sun_behind_cloud': u'\U000026c5',
    u'sun_with_face': u'\U0001f31e',
    u'sunflower': u'\U0001f33b',
    u'sunrise': u'\U0001f305',
    u'sunrise_over_mountains': u'\U0001f304',
    u'sunset_over_buildings': u'\U0001f307',
    u'surfer': u'\U0001f3c4',
    u'sushi': u'\U0001f363',
    u'suspension_railway': u'\U0001f69f',
    u'swimmer': u'\U0001f3ca',
    u'synagogue': u'\U0001f54D',
    u'syringe': u'\U0001f489',
    u't-shirt': u'\U0001f455',
    u'table_tennis_paddle_and_ball': u'\U0001f3D3',
    u'taco': u'\U0001f32e',
    u'tanabata_tree': u'\U0001f38b',
    u'tangerine': u'\U0001f34a',
    u'taurus': u'\U00002649',
    u'taxi': u'\U0001f695',
    u'teacup_without_handle': u'\U0001f375',
    u'tear-off_calendar': u'\U0001f4c6',
    u'telephone_receiver': u'\U0001f4De',
    u'telescope': u'\U0001f52D',
    u'television': u'\U0001f4fa',
    u'tennis_racquet_and_ball': u'\U0001f3be',
    u'tent': u'\U000026fa',
    u'thermometer': u'\U0001f321',
    u'thinking_face': u'\U0001f914',
    u'thought_balloon': u'\U0001f4aD',
    u'three_button_mouse': u'\U0001f5b1',
    u'thumbs_down_sign': u'\U0001f44e',
    u'thumbs_up_sign': u'\U0001f44D',
    u'thunder_cloud_and_rain': u'\U000026c8',
    u'ticket': u'\U0001f3ab',
    u'tiger': u'\U0001f405',
    u'tiger_face': u'\U0001f42f',
    u'timer_clock': u'\U000023f2',
    u'tired_face': u'\U0001f62b',
    u'toilet': u'\U0001f6bD',
    u'tokyo_tower': u'\U0001f5fc',
    u'tomato': u'\U0001f345',
    u'tongue': u'\U0001f445',
    u'top_hat': u'\U0001f3a9',
    u'top_with_upwards_arrow_above': u'\U0001f51D',
    u'trackball': u'\U0001f5b2',
    u'tractor': u'\U0001f69c',
    u'trade_mark_sign': u'\U00002122',
    u'train': u'\U0001f686',
    u'tram': u'\U0001f68a',
    u'tram_car': u'\U0001f68b',
    u'triangular_flag_on_post': u'\U0001f6a9',
    u'triangular_ruler': u'\U0001f4D0',
    u'trident_emblem': u'\U0001f531',
    u'trolleybus': u'\U0001f68e',
    u'trophy': u'\U0001f3c6',
    u'tropical_drink': u'\U0001f379',
    u'tropical_fish': u'\U0001f420',
    u'trumpet': u'\U0001f3ba',
    u'tulip': u'\U0001f337',
    u'turkey': u'\U0001f983',
    u'turtle': u'\U0001f422',
    u'twisted_rightwards_arrows': u'\U0001f500',
    u'two_hearts': u'\U0001f495',
    u'two_men_holding_hands': u'\U0001f46c',
    u'two_women_holding_hands': u'\U0001f46D',
    u'umbrella': u'\U00002602',
    u'umbrella_on_ground': u'\U000026f1',
    u'umbrella_with_rain_drops': u'\U00002614',
    u'unamused_face': u'\U0001f612',
    u'unicorn_face': u'\U0001f984',
    u'up-pointing_red_triangle': u'\U0001f53a',
    u'up-pointing_small_red_triangle': u'\U0001f53c',
    u'up_down_arrow': u'\U00002195',
    u'upside-down_face': u'\U0001f643',
    u'upwards_black_arrow': u'\U00002b06',
    u'vertical_traffic_light': u'\U0001f6a6',
    u'vibration_mode': u'\U0001f4f3',
    u'victory_hand': u'\U0000270c',
    u'video_camera': u'\U0001f4f9',
    u'video_game': u'\U0001f3ae',
    u'videocassette': u'\U0001f4fc',
    u'violin': u'\U0001f3bb',
    u'virgo': u'\U0000264D',
    u'volcano': u'\U0001f30b',
    u'volleyball': u'\U0001f3D0',
    u'waning_crescent_moon_symbol': u'\U0001f318',
    u'waning_gibbous_moon_symbol': u'\U0001f316',
    u'warning_sign': u'\U000026a0',
    u'wastebasket': u'\U0001f5D1',
    u'watch': u'\U0000231a',
    u'water_buffalo': u'\U0001f403',
    u'water_closet': u'\U0001f6be',
    u'water_wave': u'\U0001f30a',
    u'watermelon': u'\U0001f349',
    u'waving_black_flag': u'\U0001f3f4',
    u'waving_hand_sign': u'\U0001f44b',
    u'waving_white_flag': u'\U0001f3f3',
    u'wavy_dash': u'\U00003030',
    u'waxing_crescent_moon_symbol': u'\U0001f312',
    u'waxing_gibbous_moon_symbol': u'\U0001f314',
    u'weary_cat_face': u'\U0001f640',
    u'weary_face': u'\U0001f629',
    u'wedding': u'\U0001f492',
    u'weight_lifter': u'\U0001f3cb',
    u'whale': u'\U0001f40b',
    u'wheel_of_dharma': u'\U00002638',
    u'wheelchair_symbol': u'\U0000267f',
    u'white_down_pointing_backhand_index': u'\U0001f447',
    u'white_exclamation_mark_ornament': u'\U00002755',
    u'white_flower': u'\U0001f4ae',
    u'white_frowning_face': u'\U00002639',
    u'white_heavy_check_mark': u'\U00002705',
    u'white_large_square': u'\U00002b1c',
    u'white_left_pointing_backhand_index': u'\U0001f448',
    u'white_medium_small_square': u'\U000025fD',
    u'white_medium_square': u'\U000025fb',
    u'white_medium_star': u'\U00002b50',
    u'white_question_mark_ornament': u'\U00002754',
    u'white_right_pointing_backhand_index': u'\U0001f449',
    u'white_small_square': u'\U000025ab',
    u'white_smiling_face': u'\U0000263a',
    u'white_square_button': u'\U0001f533',
    u'white_sun_behind_cloud': u'\U0001f325',
    u'white_sun_behind_cloud_with_rain': u'\U0001f326',
    u'white_sun_with_small_cloud': u'\U0001f324',
    u'white_up_pointing_backhand_index': u'\U0001f446',
    u'white_up_pointing_index': u'\U0000261D',
    u'wind_blowing_face': u'\U0001f32c',
    u'wind_chime': u'\U0001f390',
    u'wine_glass': u'\U0001f377',
    u'winking_face': u'\U0001f609',
    u'wolf_face': u'\U0001f43a',
    u'woman': u'\U0001f469',
    u'woman_with_bunny_ears': u'\U0001f46f',
    u'womans_boots': u'\U0001f462',
    u'womans_clothes': u'\U0001f45a',
    u'womans_hat': u'\U0001f452',
    u'womans_sandal': u'\U0001f461',
    u'womens_symbol': u'\U0001f6ba',
    u'world_map': u'\U0001f5fa',
    u'worried_face': u'\U0001f61f',
    u'wrapped_present': u'\U0001f381',
    u'wrench': u'\U0001f527',
    u'writing_hand': u'\U0000270D',
    u'yellow_heart': u'\U0001f49b',
    u'yin_yang': u'\U0000262f',
    u'zipper-mouth_face': u'\U0001f910'
}

UNICODE_EMOJI = {v: k for k, v in UNICODE_EMOJI.items()}


def emoji_name(u):
    m = u.group()
    return ' ' + UNICODE_EMOJI.get(m).title() + ' '



# -*- coding: UTF-8 -*-
import re
import unicodedata
import string
import sys
from .unicodes_codes import *
from .stopwords import *


PY2 = int(sys.version[0]) == 2

if PY2:
    from unidecode import unidecode
    TEXT_TYPE = unicode
    BINARY_TYPE = str
    STR_TYPES = (str, unicode)
    IS_CHAR = list(unicode(string.ascii_letters, 'utf-8'))
else:
    TEXT_TYPE = str
    BINARY_TYPE = bytes
    unicode = str
    STR_TYPES = (str, )
    IS_CHAR = list(string.ascii_letters)
    basestring = (str, bytes)
    unidecode = str

MAP_CHARS = dict()
MAP_CHARS.update({ord(' '): ' '})
for c in IS_CHAR:
    MAP_CHARS.update({ord(unicode(c)): c})
ENCODE = 'utf-8'
STR_PUNC = list(string.punctuation)
REGEX_HTML = re.compile(r'<[^>]*>')
REGEX_MENTIONS = re.compile(r'\S*[@](?:\[[^\]]+\]|\S+)')
REGEX_TAGS = re.compile(r'\S*[#](?:\[[^\]]+\]|\S+)')
REGEX_SMILES = re.compile(r'([j|h][aeiou]){3,}')
REGEX_VOWELS = re.compile(r'([aeiou])\1+')
REGEX_CONSONANTS = re.compile(r'([b-df-hj-np-tv-z])\1+')
REGEX_SPACES = re.compile(r' +')
REGEX_URLS = re.compile(r'(www|http|https)(?:[a-zA-Z]|[0-9]|[$-_@.&+]|\
[!*\(\),]|(?:%[0-9a-fA-F][0-9a-fA-F]))+')
MAP_TILDE = [
    ord(u'Á'), ord(u'É'), ord(u'Í'),
    ord(u'Ó'), ord(u'Ú'), ord(u'Ñ'),
    ord(u'À'), ord(u'È'), ord(u'Ì'),
    ord(u'Ò'), ord(u'Ù'), ord(u'ç'),
    ord(u'á'), ord(u'é'), ord(u'í'),
    ord(u'ó'), ord(u'ú'), ord(u'ñ'),
    ord(u'à'), ord(u'è'), ord(u'ì'),
    ord(u'ò'), ord(u'ù'), ord(u'ü'),
    ord(u'ä'), ord(u'ë'), ord(u'ï'),
    ord(u'ö'), ord(u'ü'), ord(u'ÿ'),
    ord(u'Ç')
]
REGEX_EMOJIS = re.compile(u'[\U0001F600-\U0001F64F]', re.UNICODE)


# print unidecode(u'😂'.decode(ENCODE))
class ReTexto:
    @classmethod
    def __init__(self, text):
        self.TEXT = text.rstrip()

    @classmethod
    def __repr__(self):
        return self.TEXT

    @staticmethod
    def is_unicode(v, encoding='utf-8'):
        if isinstance(encoding, basestring):
            encoding = ((encoding,),) + \
                        (('windows-1252',), (ENCODE, 'ignore'))
        if isinstance(v, BINARY_TYPE):
            for e in encoding:
                try:
                    return v.decode(*e)
                except:
                    pass
            return v
        return unicode(v)

    @classmethod
    def remove_html(self, by=''):
        try:
            return ReTexto(re.sub(REGEX_HTML, by, self.TEXT))
        except Exception as e:
            print(e)

    @classmethod
    def remove_mentions(self, by=''):
        try:
            return ReTexto(re.sub(
                                REGEX_MENTIONS,
                                by, self.is_unicode(self.TEXT)))
        except Exception as e:
            print(e)

    @classmethod
    def remove_tags(self, by=''):
        try:
            return ReTexto(re.sub(REGEX_TAGS, by, self.TEXT))
        except Exception as e:
            print(e)

    @classmethod
    def remove_smiles(self, by=''):
        try:
            return ReTexto(re.sub(REGEX_SMILES, by, self.TEXT))
        except Exception as e:
            print(e)

    @classmethod
    def remove_punctuation(self, by=''):
        l_text = []
        l_unicodes = set(UNICODE_EMOJI.keys())
        for char in list(self.TEXT):
            if not (char in STR_PUNC):
                l_text.append(char)
                continue
            l_text.append(by)
        return ReTexto(''.join(l_text))

    @classmethod
    def remove_nochars(self, preserve_tilde=False):
        chars = MAP_CHARS.keys()
        if preserve_tilde:
            chars += MAP_TILDE
        l_char = set(chars)
        l_text = []
        for char in list(self.is_unicode(self.TEXT)):
            if ord(char) in l_char:
                l_text.append(char)
                continue
        return ReTexto(''.join(l_text))

    @classmethod
    def remove_stopwords(self, lang=None):
        l_text = []
        sw = stopwords(lang)
        for char in self.split_words():
            if not (self.is_unicode(char) in sw):
                l_text.append(char)
        return ReTexto(' '.join(l_text))

    @classmethod
    def convert_specials(self):
        return ReTexto(unidecode(self.is_unicode(self.TEXT)))

    @classmethod
    def convert_emoji(self):
        text = self.TEXT
        if PY2:
            if not isinstance(self.TEXT, unicode):
                text = self.TEXT.decode('utf-8')
            r = re.sub(REGEX_EMOJIS, lambda m: emoji_name(m), text)
            r = r.encode(ENCODE)
        else:
            r = re.sub(REGEX_EMOJIS, lambda m: emoji_name(m), text)
        return ReTexto(r)

    @classmethod
    def remove_url(self, by=''):
        return ReTexto(re.sub(REGEX_URLS, '', self.TEXT))

    @classmethod
    def remove_duplicate_consonants(self):
        return ReTexto(re.sub(REGEX_CONSONANTS, r'\1', self.TEXT))

    @classmethod
    def remove_duplicate(self, r='a-z'):
        p = re.compile(r'([%s])\1+' % r)
        return ReTexto(re.sub(p, r'\1', self.TEXT))

    @classmethod
    def remove_duplicate_vowels(self):
        return ReTexto(re.sub(REGEX_VOWELS, r'\1', self.TEXT))

    @classmethod
    def remove_multispaces(self):
        return ReTexto(re.sub(REGEX_SPACES, ' ', self.TEXT))

    @classmethod
    def split_words(self, uniques=False):
        l = self.TEXT.split()
        if uniques:
            seen = set()
            l = [x for x in l if x not in seen and not seen.add(x)]
        return l

    @classmethod
    def lower(self):
        return ReTexto(self.TEXT.lower())
